"use strict";

import { checks } from "../src/checks";
import * as chai from 'chai';

const expect = chai.expect;

// Check that we are fine
describe('checks', function() {


    it('.isEmpty();', function(done) {
        expect(checks.isEmpty(undefined)).to.be.true;
        expect(checks.isEmpty({})).to.be.true;
        expect(checks.isEmpty({'x': 1})).to.be.false;
        done();
    });


    it('.isValidSessionID();', function(done) {
        expect(checks.isValidGUID('de305d54-75b4-431b-adb2-eb6b9e546014')).to.be.true;
        expect(checks.isValidGUID('HelloWolrd')).to.be.false;
        done();
    });


    it('.isValidParameter();', function(done) {
        expect(checks.isValidParameter('hello.world')).to.be.true;
        expect(checks.isValidParameter('hello-world')).to.be.true;
        expect(checks.isValidParameter('hello:world')).to.be.false;
        expect(checks.isValidParameter('hello$world')).to.be.false;
        expect(checks.isValidParameter('hello%world')).to.be.false;
        expect(checks.isValidParameter('123')).to.be.true;
        expect(checks.isValidParameter('drop;')).to.be.false;
        expect(checks.isValidParameter('"')).to.be.false;
        expect(checks.isValidParameter(";")).to.be.false;
        done();
    });



    it('.isValidGUID();', function(done) {
        expect(checks.isValidGUID('de305d54-75b4-431b-adb2-eb6b9e546014')).to.be.true;
        expect(checks.isValidGUID('de305d54-75b4-431b-adb2-eb6b9E546014')).to.be.false;
        expect(checks.isValidGUID('de305d54-75b4-431ba-db2-eb6b9e546014')).to.be.false;
        done();
    });




});
